@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version__ = '0.1.2'
+__version__ = '0.2.0'
 
 try:
     from pymongo import ASCENDING, DESCENDING  # NOQA
@@ -11,7 +11,8 @@ try:
 
     from motorengine.fields import (  # NOQA
         BaseField, StringField, BooleanField, DateTimeField,
-        UUIDField, ListField, EmbeddedDocumentField, ReferenceField
+        UUIDField, ListField, EmbeddedDocumentField, ReferenceField, URLField,
+        EmailField
     )
 except ImportError:  # NOQA
     pass  # likely setup.py trying to import version
